# Acapela Downloader but in Python
Translated over to Python from C#: https://github.com/weespin/WillFromAfarDownloader

# How to use

First download the pip package.

```
pip install acapela-downloader-py
```

Then use the 'generate_audio' function from the 'acapela' library

``` python
from acapela import generate_audio
generate_audio("Great Test", "enu_willhappy_22k_ns.bvcu", "output.mp3")
```

## Other Stuff

If you find any code from StupidTown in my package feel free to make a pull request.
